@@ -33,7 +33,8 @@
 
 #############################################################
 # -------------- Set of libraries needed:
-from .ReadData import ReadData
+import pypion
+from pypion import ReadData
 
 import matplotlib
 # Using this to stop matplotlib from using a $DISPLAY environment variable.
@@ -58,7 +59,7 @@ plt.rc('font', weight='bold')  # <-------------
 
 # -------------- Class to plot the data from 2d Silo files.
 
-class Plotting2d(ReadData):
+class Plotting2d(ReadData.ReadData):
     def plotsilo_2d(self, lim_min, lim_max, fig, var1, var2):
         xmin = (self.xmin() * u.cm).to(u.pc)  # Set data to units of parsecs.
         xmax = (self.xmax() * u.cm).to(u.pc)
@@ -168,7 +169,7 @@ class Plotting2d(ReadData):
 
         return fig
 
-class Plotting3d(ReadData):
+class Plotting3d(ReadData.ReadData):
     def XZXYslice(self, param, Fig, var1):
 
         # assign necessary data to arrays.
@@ -230,19 +231,3 @@ class Plotting3d(ReadData):
 
         return fig
 
-'''
-if var1[0] == 'B3D_mag':
-    magx = self.get_3Darray('MagneticFieldX')
-    magy = self.get_3Darray('MagneticFieldY')
-    magz = self.get_3Darray('MagneticFieldZ')
-
-    mag = np.sqrt((magx ** 2) + (magy ** 2) + (magz ** 2))
-
-    log_dx = np.log10(mag[var1[6], :, :])
-    log_dy = np.log10(mag[:, var1[6], :])
-'''
-
-#arr = ('files/zeta_10uG_level00_0000.00100000.silo', 'files/zeta_10uG_level01_0000.00100000.silo', 'files/zeta_10uG_level02_0000.00100000.silo')
-
-#a = Plotting(arr).XZXYslice('Density')
-#plt.savefig("test.png", bbox_inches='tight', dpi=300)
