@@ -25,12 +25,14 @@
 
 # -------------- Set of libraries needed:
 import numpy as np
-from .SiloHeader_data import OpenData
+import pypion
+from pypion import SiloHeader_data
+
 
 # --------------Class to access each 2D sub-domain and save density, temperature, etc. data:
 
 
-class ReadData(OpenData):
+class ReadData(SiloHeader_data.OpenData):
 
     # Function to read 1D data from multiple nested grid levels from
     # a Silo file, and return the data as numpy arrays with extents.
